@@ -6,10 +6,10 @@ from os import path
 
 import paddlehub as hub
 
-cpu_num = os.system('cat /proc/cpuinfo | grep "processor"| wc -l')
-os.system('export CPU_NUM=%d' % (cpu_num if cpu_num else 2))
+_cpu_num = os.system('cat /proc/cpuinfo | grep "processor"| wc -l')
+os.system('export CPU_NUM=%d' % (_cpu_num if _cpu_num else 2))
 
-os.system('export FLAGS_eager_delete_tensor_gb=0.0')
+os.system('export FLAGS_eager_delete_tensor_gb=0')
 # os.system('export CUDA_VISIBLE_DEVICES=0')
 
 print(':: CPU_NUM: %s' % os.getenv('CPU_NUM'))
